#ifndef NT2_INCLUDE_FUNCTIONS_BITFLOATING_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITFLOATING_HPP_INCLUDED

#include <nt2/ieee/include/functions/bitfloating.hpp>

#endif
